@@ -18,6 +18,48 @@ from robotidy.utils import GlobalFormattingConfig, split_args_from_name_or_path
 
 
 INCLUDE_EXT = ('.robot', '.resource')
+HELP_MSG = f"""
+Version: {__version__}
+
+Robotidy is a tool for formatting Robot Framework source code.
+See examples at the end of this help message too see how you can use Robotidy.
+For more documentation check README section at https://github.com/MarketSquare/robotframework-tidy
+"""
+EPILOG = """
+Examples:
+  # Format `path/to/src.robot` file
+  $ robotidy path/to/src.robot
+
+  # Format every Robot Framework file inside `dir_name` directory
+  $ robotidy dir_name
+
+  # List available transformers:
+  $ robotidy --list-transformers
+  
+  # Display transformer documentation
+  $ robotidy --describe-transformer <TRANSFORMER_NAME>
+
+  # Format `src.robot` file using `SplitTooLongLine` transformer only
+  $ robotidy --transform SplitTooLongLine src.robot
+
+  # Format `src.robot` file using `SplitTooLongLine` transformer only and configured line length 140
+  $ robotidy --transform SplitTooLongLine:line_length=140 src.robot
+
+"""
+
+
+class RawHelp(click.Command):
+    def format_help_text(self, ctx, formatter):
+        if self.help:
+            formatter.write_paragraph()
+            for line in self.help.split('\n'):
+                formatter.write_text(line)
+
+    def format_epilog(self, ctx, formatter):
+        if self.epilog:
+            formatter.write_paragraph()
+            for line in self.epilog.split('\n'):
+                formatter.write_text(line)
 
 
 class TransformType(click.ParamType):
@@ -85,7 +127,7 @@ def read_config(ctx: click.Context, param: click.Parameter, value: Optional[str]
         raise click.FileError(
             filename=value, hint=f"Error reading configuration file: {e}"
         )
-
+    click.echo(f'Reading config from {value}')
     if not config:
         return None
     else:
@@ -142,7 +184,7 @@ def get_paths(src: Tuple[str, ...]):
     return sources
 
 
-@click.command()
+@click.command(cls=RawHelp, help=HELP_MSG, epilog=EPILOG)
 @click.option(
     '--transform',
     type=TransformType(),
@@ -162,20 +204,29 @@ def get_paths(src: Tuple[str, ...]):
 @click.option(
     '--overwrite/--no-overwrite',
     default=True,
-    help='Overwrite source files.'
+    help='Overwrite source files.',
+    show_default=True
 )
 @click.option(
     '--diff',
     is_flag=True,
-    help='Output diff of each processed file.'
+    help='Output diff of each processed file.',
+    show_default=True
+)
+@click.option(
+    '--check',
+    is_flag=True,
+    help="Don't overwrite files and just return status. Return code 0 means nothing would change. "
+         "Return code 1 means that at least 1 file would change. Any internal error will overwrite this status.",
+    show_default=True
 )
 @click.option(
     '-s',
     '--spacecount',
     type=click.types.INT,
     default=4,
-    help='The number of spaces between cells in the plain text format.\n'
-         'Default is 4.'
+    help='The number of spaces between cells in the plain text format.\n',
+    show_default=True
 )
 @click.option(
     '-l',
@@ -185,13 +236,15 @@ def get_paths(src: Tuple[str, ...]):
     help="Line separator to use in outputs. The default is 'native'.\n"
          "native:  use operating system's native line separators\n"
          "windows: use Windows line separators (CRLF)\n"
-         "unix:    use Unix line separators (LF)"
+         "unix:    use Unix line separators (LF)",
+    show_default=True
 )
 @click.option(
     '-p',
     '--usepipes',
     is_flag=True,
-    help="Use pipe ('|') as a column separator in the plain text format."
+    help="Use pipe ('|') as a column separator in the plain text format.",
+    show_default=True
 )
 @click.option(
     '-sl',
@@ -199,7 +252,8 @@ def get_paths(src: Tuple[str, ...]):
     default=None,
     type=int,
     help="Limit robotidy only to selected area. If --endline is not provided, format text only at --startline. "
-         "Line numbers start from 1."
+         "Line numbers start from 1.",
+    show_default=True
 )
 @click.option(
     '-el',
@@ -207,12 +261,14 @@ def get_paths(src: Tuple[str, ...]):
     default=None,
     type=int,
     help="Limit robotidy only to selected area. "
-         "Line numbers start from 1."
+         "Line numbers start from 1.",
+    show_default=True
 )
 @click.option(
     '-v',
     '--verbose',
-    is_flag=True
+    is_flag=True,
+    show_default=True
 )
 @click.option(
     "--config",
@@ -248,6 +304,7 @@ def cli(
         src: Tuple[str, ...],
         overwrite: bool,
         diff: bool,
+        check: bool,
         spacecount: int,
         lineseparator: str,
         usepipes: bool,
@@ -290,7 +347,8 @@ def cli(
         overwrite=overwrite,
         show_diff=diff,
         formatting_config=formatting_config,
-        verbose=verbose
+        verbose=verbose,
+        check=check
     )
-    tidy.transform_files()
-
+    status = tidy.transform_files()
+    ctx.exit(status)
